@@ -28,7 +28,7 @@ class DateEditArgs(CommonParameterWidgetArgs):
 
 
 class DateEdit(CommonParameterWidget):
-    HIDE_DEFAULT_WIDGET = True
+    HIDE_DEFAULT_VALUE_WIDGET = True
     SET_DEFAULT_ON_INIT = True
 
     _WidgetArgsClass = DateEditArgs
